SOSCleaner
==========

[![Build Status](https://travis-ci.org/jduncan-rva/soscleaner.svg?branch=master)](https://travis-ci.org/RedHatGov/soscleaner) [![Coverage Status](https://coveralls.io/repos/github/jduncan-rva/soscleaner/badge.svg?branch=master)](https://coveralls.io/github/jduncan-rva/soscleaner?branch=master) [![PyPI version](https://badge.fury.io/py/soscleaner.svg)](https://badge.fury.io/py/soscleaner)


Purpose
-------
SOSCleaner is a tool to consistently obfuscate sensitive information in large datasets like Red Hat sosreports. It works on any data set, from 1 file to thousands.

Documenation
----------------
Documenation has been moved to ReadTheDocs.

https://soscleaner.readthedocs.io

Important Links
--------------------
* **Source Code** - https://github.com/jduncan-rva/soscleaner
* **Issues** - https://github.com/jduncan-rva/soscleaner/issues
* **Project** - Tracking https://github.com/jduncan-rva/soscleaner/projects/1
* **RPMs** - https://copr.fedorainfracloud.org/coprs/jduncan/soscleaner/
* **PyPi** - https://pypi.org/project/soscleaner/
* **Code Coverage** - https://coveralls.io/github/jduncan-rva/soscleaner
* **CI/CD** - https://travis-ci.com/jduncan-rva/soscleaner
* **Docs** - https://soscleaner.readthedocs.io
